class AlbumImage(object):

	def __init__(self, manager, player):
		"""
		Initialize object.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__init_attributes(manager, player)
		self.__precompile_methods()
		self.__set_property()
		self.__signal_id_1 = manager.connect("destroy", self.__destroy_cb)
		self.__signal_id_2 = player.connect("album-image-found", self.__image_found_cb)
		self.__signal_id_3 = player.connect("no-album-image-found", self.__no_image_found_cb)
		self.__signal_id_4 = player.connect("streamer-is-stopped", self.__no_image_found_cb)
		self.__signal_id_5 = player.connect("stream-error", self.__error_cb)
		self.__signal_id_6 = player.connect("playlist-error", self.__error_cb)
		self.__signal_id_7 = player.connect("streamer-is-busy", self.__is_busy_cb)

	def __init_attributes(self, manager, player):
		"""
		Initialize data attributes.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__player = player
		self.__manager = manager
		self.__image = player.glade.get_widget("AlbumImage")
		self.__pixbuf = self.__image.get_pixbuf()
		return

	def __set_property(self):
		"""
		Set default properties.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.
		"""
		self.__image.set_property("sensitive", True)
		if self.__player.album_image: self.__set_image(self.__player.album_image)
		if self.__player.is_busy: self.__set_info_image()
		return

	def __set_image(self, image):
		"""
		Set album image.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.

		@param image: Reference to an album image file.
		@type image: A String object.
		"""
		self.__player.response()
		self.__image.clear()
		from gtk.gdk import pixbuf_new_from_file, INTERP_HYPER
		self.__image.set_from_pixbuf(pixbuf_new_from_file(image).scale_simple(96, 96, INTERP_HYPER))
		self.__player.response()
		return

	def __set_default_image(self):
		"""
		Default image.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.
		"""
		self.__player.response()
		self.__image.set_from_pixbuf(self.__pixbuf)
		self.__player.response()
		return

	def __set_error_image(self):
		"""
		Show error image.

		@param self: Reference to the Image instance.
		@type self: An Image object.
		"""
		self.__player.response()
		from gtk import STOCK_DIALOG_ERROR
		self.__image.clear()
		self.__image.set_property("icon-name", "gtk-dialog-error")
		self.__image.set_property("pixel-size", 96)
		self.__player.response()
		return

	def __set_info_image(self):
		"""
		Show information image when gathering metadata.

		@param self: Reference to the Image instance.
		@type self: An Image object.
		"""
		self.__player.response()
		from gtk import STOCK_DIALOG_INFO
		self.__image.clear()
		self.__image.set_property("pixel-size", 96)
		self.__image.set_property("icon-name", "gtk-dialog-info")
		self.__image.set_property("pixel-size", 96)
		self.__player.response()
		return

	def __precompile_methods(self):
		"""
		Use psyco to optimize some methods.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.
		"""
		try:
			from psyco import bind
			bind(self.__set_image)
			bind(self.__set_default_image)
			bind(self.__set_info_image)
			bind(self.__set_error_image)
		except ImportError:
			pass
		return

	def __image_found_cb(self, player, image):
		"""
		Handles callback when an album image is found.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.

		@param player: Reference to the Player instance.
		@type player: A Player object.

		@param image: Reference to an image.
		@type image: A String object.
		"""
		self.__set_image(image)
		return

	def __no_image_found_cb(self, *args):
		"""
		Handles callback when no image is found.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.
		"""
		self.__set_default_image()
		return

	def __error_cb(self, *args):
		"""
		Handles callback when an error occurs.

		@param self: Reference to the Image instance.
		@type self: An Image object.
		"""
		self.__set_error_image()
		return

	def __is_busy_cb(self, *args):
		"""
		Handles callback when the "streamer-is-busy" signal is emitted.

		@param self: Reference to the Image instance.
		@type self: An Image object.
		"""
		self.__set_info_image()
		return

	def __destroy_cb(self, *args):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the AlbumImage instance.
		@type self: An AlbumImage object.
		"""
		from Striim.utils import delete_attributes, disconnect_signal
		disconnect_signal(self.__signal_id_1, self.__manager)
		disconnect_signal(self.__signal_id_2, self.__player)
		disconnect_signal(self.__signal_id_3, self.__player)
		disconnect_signal(self.__signal_id_4, self.__player)
		disconnect_signal(self.__signal_id_5, self.__player)
		disconnect_signal(self.__signal_id_6, self.__player)
		self.__image.destroy()
		delete_attributes(self)
		del self
		self = None
		return
